<?php
/*
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2005 Bharat Mediratta
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Id: UserDB.php,v 1.11.8.1 2005/03/10 02:30:00 cryptographite Exp $
 *
 * Hack to enable Gallery Users under PHP-NUKE with their real permissions
 * by U.Schroeter, 29.5.2005
 *
 */
?>
<?php
class Nuke5_UserDB extends Abstract_UserDB {
	var $db;
	var $fields;
/*  Add original class Gallery_UserDB extends Abstract_UserDB extensions
    to allow search for Gallery UIDs for related PHP-NUKE users
 */
	var $userMap;
	var $nobody;
	var $everybody;
	var $loggedIn;
	var $version;
/*  end hack modification */
	
	function Nuke5_UserDB() {
		global $gallery;

		$this->db = $gallery->database{"nuke"};
		$this->prefix = $gallery->database{"user_prefix"};

		/*  original class Gallery_UserDB extends Abstract_UserDB extensions */
                /*  to get Gallery UID of related PHP-Nuke user                      */
		$userDir = $gallery->app->userDir;

		// assuming revision 4 ensures that if the user_version is 
		// not properly read from file due to the file format changes
		// that we perform the necessary upgrade.
		$this->version = 4;

		$this->userMap = array();

		if (!fs_file_exists($userDir)) {
			if (!mkdir($userDir, 0777)) {
				echo gallery_error(_("Unable to create dir") .": $userDir");
				return;
			}
		} else {
			if (!fs_is_dir($userDir)) {
				echo gallery_error(sprintf(_("%s exists, but is not a directory!"),
							$userDir));
				return;
			}
		}

		if (!fs_file_exists("$userDir/.htaccess")) {
			if (is_writeable($userDir)) {
				$fd = fs_fopen("$userDir/.htaccess", "w");
				fwrite($fd, "Order deny,allow\nDeny from all\n");
				fclose($fd);
			} else {
				echo gallery_error(sprintf(_("The folder folder which contain your userinformation (%s) is not writable."), 
								$userDir));
				exit;
			}
		}


		if (fs_file_exists("$userDir/userdb.dat") && is_writeable("$userDir/userdb.dat")) {
			$tmp = getFile("$userDir/userdb.dat");

			/* 
			 * We moved from class UserDB.php to class Gallery_UserDB.php
			 * in v1.2.  If we're upgrading from an old version, just ignore
			 * the old cache file (it'll get rebuilt automatically).
			 */
			if (strcmp(substr($tmp, 0, 12), 'O:6:"userdb"')) {
				foreach (unserialize($tmp) as $k => $v) {
					$this->$k = $v;
				}
			}
		} elseif (fs_file_exists("$userDir/userdb.dat") && !is_writeable("$userDir/userdb.dat")) {
			echo gallery_error(_("Your Userfile is not writeable"));
			exit;
		}

		/*  end hack modification */

		
		if (!$this->nobody) {
			$this->nobody = new NobodyUser();
		}

		if (!$this->everybody) {
			$this->everybody = new EverybodyUser();
		}

		if (!$this->loggedIn) {
			$this->loggedIn = new LoggedInUser();
		}


		/* now append original nuke5 code              */
		$this->fields = $gallery->database{'fields'};
	}


	function getUidList() {
		$uidList = array();
		$db = $this->db;

		$results = $db->query('select ' . $this->fields{'uid'} .
				      ' from ' . $this->prefix . 'users');
		while ($row = $db->fetch_row($results)) {
			array_push($uidList, $row[0]);
		}
		array_push($uidList, $this->nobody->getUid());
		array_push($uidList, $this->everybody->getUid());
		array_push($uidList, $this->loggedIn->getUid());

		sort($uidList);
		return $uidList;
	}

	function getUserByUsername($username, $level=0) {

		global $gallery;

                /* added addtl. original class Gallery_UserDB extends  */
                /* Abstract_UserDB extensions code to get Gallery UID  */
                /* instead of PHP-NUKE UID                             */

		if ($level > 1) {
			// We've recursed too many times.  Abort;
			return;
		}

		if (!strcmp($username, $this->nobody->getUsername())) {
			return $this->nobody;
		} else if (!strcmp($username, $this->everybody->getUsername())) {
			return $this->everybody;
		} else if (!strcmp($username, $this->loggedIn->getUsername())) {
			return $this->loggedIn;
		}

		if (!isset($this->userMap[$username])) {
			/* Original Gallery_UserDB code crashes in rebuildUserMap() */
                        /* if PHP-NUKE user is undefined in Gallery                 */
                        /* so workaround with empty tmpuid and original nuke5 code  */
			/* $this->rebuildUserMap(); */
			/*  User does not exist?    */
			$tmpuid = "";
			$user = new Nuke5_User();
			$user->loadByUsername($username,$tmpuid);
		} else {
			$uid = $this->userMap[$username];
			$uid = $this->convertUidToNewFormat($uid);
                	$tmpuid = $uid;
	                /* echo $tmpuid;      CORRECT GALLERY UID !!!!   */
			/* $user = $this->getUserByUid($uid); */
			$user = new Nuke5_User();

			/* pass correct Gallery UID in tmpuid to LoadByUsername()  */
			$user->loadByUsername($username,$tmpuid);
		}
		return $user;
	}

	function getUserByUid($uid) {
		global $gallery;
		$userDir = $gallery->app->userDir;

		if (!$uid || !strcmp($uid, $this->nobody->getUid())) {
			return $this->nobody;
		} else if (!strcmp($uid, $this->everybody->getUid())) {
			return $this->everybody;
		} else if (!strcmp($uid, $this->loggedIn->getUid())) {
			return $this->loggedIn;
		}

		$user = new Nuke5_User();
		$user->loadByUid($uid);
		return $user;
	}
}

?>
